@@ -37,9 +37,9 @@ from typing import (
     Iterable,
     Literal,
     NoReturn,
+    TypeAlias,
     TypedDict,
     TypeVar,
-    Union,
     overload,
 )
 from weakref import WeakSet
@@ -51,7 +51,7 @@ else:
     from functools import lru_cache
 
 if TYPE_CHECKING:
-    from typing_extensions import Self
+    from typing_extensions import NotRequired, Self
 
 # Bokeh imports
 from ..settings import settings
@@ -71,8 +71,6 @@ from .serialization import (
 from .types import ID
 
 if TYPE_CHECKING:
-    from typing_extensions import NotRequired, TypeAlias
-
     from ..client.session import ClientSession
     from ..server.session import ServerSession
     from .property.bases import Property
@@ -99,7 +97,7 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 if TYPE_CHECKING:
-    Setter: TypeAlias = Union[ClientSession, ServerSession]
+    Setter: TypeAlias = ClientSession | ServerSession
 
 C = TypeVar("C", bound=type["HasProps"])
 
@@ -747,15 +745,18 @@ class HasProps(Serializable, metaclass=MetaHasProps):
         '''
         self.apply_theme(property_values={})
 
-    def clone(self) -> Self:
-        ''' Duplicate a HasProps object.
+    def clone(self, **overrides: Any) -> Self:
+        ''' Duplicate a ``HasProps`` object.
 
-        This creates a shallow clone of the original model, i.e. any
-        mutable containers or child models will not be duplicated.
+        This creates a shallow clone of the original model, i.e. any mutable
+        containers or child models will not be duplicated. Allows to override
+        particular properties while cloning.
 
         '''
         attrs = self.properties_with_values(include_defaults=False, include_undefined=True)
-        return self.__class__(**{key: val for key, val in attrs.items() if val is not Undefined})
+        existing = {key: val for key, val in attrs.items() if val is not Undefined}
+        properties = {**existing, **overrides}
+        return self.__class__(**properties)
 
 KindRef = Any # TODO
 
