@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -28,7 +28,7 @@ from ...util.dataclasses import Unspecified
 from ...util.serialization import convert_datetime_type, convert_timedelta_type
 from ...util.strings import nice_join
 from .. import enums
-from .color import Color
+from .color import ALPHA_DEFAULT_HELP, COLOR_DEFAULT_HELP, Color
 from .datetime import Datetime, TimeDelta
 from .descriptors import DataSpecPropertyDescriptor, UnitsSpecPropertyDescriptor
 from .either import Either
@@ -106,7 +106,7 @@ class DataSpec(Either):
 
         glyph.x = 10
 
-    Alternatively, maybe the each glyph that gets drawn should have a
+    Alternatively, maybe each glyph that gets drawn should have a
     different location, according to the "pressure" column of a data
     source. In this case we would like to be able to write:
 
@@ -127,7 +127,7 @@ class DataSpec(Either):
 
         glyph.x = "pressure"  # => { 'field': 'pressure' }
 
-    When these underlying dictionary dictionary values are received in
+    When these underlying dictionary values are received in
     the browser, BokehJS knows how to interpret them and take the correct,
     expected action (i.e., draw the glyph at ``x=10``, or draw the glyph
     with ``x`` coordinates from the "pressure" column). In this way, both
@@ -275,13 +275,8 @@ class NumberSpec(DataSpec):
 
 class AlphaSpec(NumberSpec):
 
-    _default_help = """\
-    Acceptable values are floating-point numbers between 0 and 1 (0 being
-    transparent and 1 being opaque).
-    """
-
     def __init__(self, default=1.0, *, help: str | None = None) -> None:
-        help = f"{help or ''}\n{self._default_help}"
+        help = f"{help or ''}\n{ALPHA_DEFAULT_HELP}"
         super().__init__(default=default, help=help, accept_datetime=False, accept_timedelta=False)
 
 class NullStringSpec(DataSpec):
@@ -293,8 +288,8 @@ class StringSpec(DataSpec):
 
     Because acceptable fixed values and field names are both strings, it can
     be necessary explicitly to disambiguate these possibilities. By default,
-    string values are interpreted as fields, but the |value| function can be
-    used to specify that a string should interpreted as a value:
+    string values are interpreted as fields, but you can use the |value| function
+    to specify that a string is interpreted as a value:
 
     .. code-block:: python
 
@@ -310,7 +305,7 @@ class FontSizeSpec(DataSpec):
     """ A |DataSpec| property that accepts font-size fixed values.
 
     The ``FontSizeSpec`` property attempts to first interpret string values as
-    font sizes (i.e. valid CSS length values). Otherwise string values are
+    font sizes (i.e. valid CSS length values). Otherwise, string values are
     interpreted as field names. For example:
 
     .. code-block:: python
@@ -368,7 +363,7 @@ class HatchPatternSpec(DataSpec):
     """ A |DataSpec| property that accepts hatch pattern types as fixed values.
 
     The ``HatchPatternSpec`` property attempts to first interpret string values
-    as hatch pattern types. Otherwise string values are interpreted as field
+    as hatch pattern types. Otherwise, string values are interpreted as field
     names. For example:
 
     .. code-block:: python
@@ -388,7 +383,7 @@ class MarkerSpec(DataSpec):
     """ A |DataSpec| property that accepts marker types as fixed values.
 
     The ``MarkerSpec`` property attempts to first interpret string values as
-    marker types. Otherwise string values are interpreted as field names.
+    marker types. Otherwise, string values are interpreted as field names.
     For example:
 
     .. code-block:: python
@@ -555,20 +550,8 @@ class ColorSpec(DataSpec):
 
     """
 
-    _default_help = """\
-    Acceptable values are:
-
-    - any of the |named CSS colors|, e.g ``'green'``, ``'indigo'``
-    - RGB(A) hex strings, e.g., ``'#FF0000'``, ``'#44444444'``
-    - CSS4 color strings, e.g., ``'rgba(255, 0, 127, 0.6)'``, ``'rgb(0 127 0 / 1.0)'``
-    - a 3-tuple of integers (r, g, b) between 0 and 255
-    - a 4-tuple of (r, g, b, a) where r, g, b are integers between 0..255 and a is between 0..1
-    - a 32-bit unsiged integers using the 0xRRGGBBAA byte order pattern
-
-    """
-
     def __init__(self, default, *, help: str | None = None) -> None:
-        help = f"{help or ''}\n{self._default_help}"
+        help = f"{help or ''}\n{COLOR_DEFAULT_HELP}"
         super().__init__(Nullable(Color), default=default, help=help)
 
     @classmethod
@@ -600,7 +583,7 @@ class ColorSpec(DataSpec):
             True, if the value could be a color tuple
 
         """
-        return isinstance(val, tuple) and len(val) in (3, 4) and all(isinstance(v, (float, int)) for v in val)
+        return isinstance(val, tuple) and len(val) in (3, 4) and all(isinstance(v, float | int) for v in val)
 
     def prepare_value(self, cls, name, value):
         # Some explanation is in order. We want to accept tuples like
