@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -97,6 +97,7 @@ from typing import (
     Any,
     Callable,
     Generic,
+    TypeGuard,
     TypeVar,
 )
 
@@ -106,8 +107,6 @@ from .singletons import Undefined
 from .wrappers import PropertyValueColumnData, PropertyValueContainer
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeGuard
-
     from ...document.events import DocumentPatchedEvent
     from ..has_props import HasProps, Setter
     from .alias import Alias, DeprecatedAlias
@@ -204,7 +203,7 @@ This is a backwards compatibility alias for the {self.aliased_name!r} property.
 
     def __get__(self, obj: HasProps | None, owner: type[HasProps] | None) -> T:
         if obj is not None:
-            # Warn only when accesing descriptor's value, otherwise there would
+            # Warn only when accessing descriptor's value, otherwise there would
             # be a lot of spurious warnings from parameter resolution, etc.
             self._warn()
         return super().__get__(obj, owner)
@@ -324,7 +323,7 @@ class PropertyDescriptor(Generic[T]):
             class_name = obj.__class__.__name__
             raise RuntimeError(f"Cannot set a property value {self.name!r} on a {class_name} instance before HasProps.__init__")
 
-        if self.property.readonly:
+        if self.property.readonly and obj._initialized:
             class_name = obj.__class__.__name__
             raise RuntimeError(f"{class_name}.{self.name} is a readonly property")
 
@@ -485,7 +484,7 @@ class PropertyDescriptor(Generic[T]):
     @classmethod
     def is_unstable(cls, value: Any) -> TypeGuard[Callable[[], Any]]:
         from .instance import InstanceDefault
-        return isinstance(value, (FunctionType, InstanceDefault))
+        return isinstance(value, FunctionType | InstanceDefault)
 
     def _get(self, obj: HasProps) -> T:
         """ Internal implementation of instance attribute access for the
