@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -46,7 +46,12 @@ from jinja2 import Template
 from ..core.enums import HoldPolicyType
 from ..core.has_props import is_DataModel
 from ..core.query import find, is_single_string_selector
-from ..core.serialization import Deserializer, Serialized, Serializer
+from ..core.serialization import (
+    Deserializer,
+    Serialized,
+    Serializer,
+    UnknownReferenceError,
+)
 from ..core.templates import FILE
 from ..core.types import ID
 from ..core.validation import check_integrity, process_validation_issues
@@ -113,8 +118,6 @@ class Document:
     models to JSON. Accordingly,  the ``Document`` is thus the smallest unit
     of serialization for Bokeh.
 
-    .. autoclasstoc::
-
     '''
 
     callbacks: DocumentCallbackManager
@@ -184,7 +187,7 @@ class Document:
 
     @template.setter
     def template(self, template: Template) -> None:
-        if not isinstance(template, (Template, str)):
+        if not isinstance(template, Template | str):
             raise ValueError("document template must be Jinja2 template or a string")
         self._template = template
 
@@ -366,7 +369,19 @@ class Document:
 
         '''
         deserializer = Deserializer(list(self.models), setter=setter)
-        patch: PatchJson = deserializer.deserialize(patch_json)
+
+        try:
+            patch: PatchJson = deserializer.deserialize(patch_json)
+        except UnknownReferenceError as error:
+            if self.models.seen(error.id):
+                logging.warning(f"""\
+Dropping a patch because it contains a previously known reference (id={error.id!r}). \
+Most of the time this is harmless and usually a result of updating a model on one \
+side of a communications channel while it was being removed on the other end.\
+""")
+                return
+            else:
+                raise
 
         events = patch["events"]
         assert isinstance(events, list) # list[DocumentPatched]
@@ -740,11 +755,14 @@ class Document:
         doc_json = DocJson(
             version=__version__,
             title=self.title,
-            defs=defs,
             roots=roots,
-            callbacks=callbacks,
         )
 
+        if data_models:
+            doc_json["defs"] = defs
+        if self.callbacks._js_event_callbacks:
+            doc_json["callbacks"] = callbacks
+
         self.models.flush_synced()
         return doc_json
 
@@ -795,19 +813,19 @@ class Document:
 
         with self.models.freeze():
             while self.roots:
-                r = next(iter(self.roots))
-                self.remove_root(r)
-                roots.append(r)
+                root = next(iter(self.roots))
+                self.remove_root(root)
+                roots.append(root)
 
-        for r in roots:
-            if r.document is not None:
-                raise RuntimeError("Somehow we didn't detach %r" % (r))
+        for root in roots:
+            if root.document is not None:
+                raise RuntimeError(f"Somehow we didn't detach {root!r}")
 
         if len(self.models) != 0:
             raise RuntimeError(f"_all_models still had stuff in it: {self.models!r}")
 
-        for r in roots:
-            dest_doc.add_root(r)
+        for root in roots:
+            dest_doc.add_root(root)
 
         dest_doc.title = self.title
 
