@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,7 +21,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 # Bokeh imports
 from ...core.enums import (
@@ -68,7 +68,9 @@ from ...core.validation import error
 from ...core.validation.errors import (
     BAD_COLUMN_NAME,
     NON_MATCHING_DATA_SOURCES_ON_LEGEND_ITEM_RENDERERS,
+    NON_MATCHING_SCALE_BAR_UNIT,
 )
+from ...events import LegendItemClick
 from ...model import Model
 from ..formatters import TickFormatter
 from ..labeling import LabelingPolicy, NoOverlap
@@ -79,6 +81,10 @@ from ..tickers import FixedTicker, Ticker
 from .annotation import Annotation
 from .dimensional import Dimensional, MetricLength
 
+if TYPE_CHECKING:
+    from ...util.callback_manager import EventCallback as PyEventCallback
+    from ..callbacks import Callback as JsEventCallback
+
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -517,6 +523,14 @@ class Legend(Annotation):
     """).accepts(List(Tuple(String, List(Instance(GlyphRenderer)))),
         lambda items: [LegendItem(label=item[0], renderers=item[1]) for item in items])
 
+    def on_click(self, handler: PyEventCallback) -> None:
+        """ Set up a handler for legend item clicks. """
+        self.on_event(LegendItemClick, handler)
+
+    def js_on_click(self, handler: JsEventCallback) -> None:
+        """ Set up a JavaScript handler for legend item clicks. """
+        self.js_on_event(LegendItemClick, handler)
+
 class ScaleBar(Annotation):
     """ Represents a scale bar annotation.
     """
@@ -525,6 +539,11 @@ class ScaleBar(Annotation):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
 
+    @error(NON_MATCHING_SCALE_BAR_UNIT)
+    def _check_non_matching_scale_bar_unit(self):
+        if not self.dimensional.is_known(self.unit):
+            return str(self)
+
     range = Either(Instance(Range), Auto, default="auto", help="""
     The range for which to display the scale.
 
@@ -585,8 +604,7 @@ class ScaleBar(Annotation):
 
     * ``@{value}`` The current value. Optionally can provide a number
       formatter with e.g. ``@{value}{%.2f}``.
-    * ``@{unit}`` The unit of measure, by default in the short form.
-      Optionally can provide a format ``@{unit}{short}`` or ``@{unit}{long}``.
+    * ``@{unit}`` The unit of measurement.
 
     """)
 
