@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -7,8 +7,6 @@
 ''' Display a variety of visual shapes whose attributes can be associated
 with data columns from ``ColumnDataSources``.
 
-
-
 The full list of glyphs is below:
 
 .. toctree::
@@ -40,6 +38,7 @@ log = logging.getLogger(__name__)
 from ..core.enums import (
     Direction,
     ImageOrigin,
+    OutlineShapeName,
     Palette,
     StepMode,
     enumeration,
@@ -49,7 +48,9 @@ from ..core.properties import (
     AngleSpec,
     Bool,
     DataSpec,
+    Dict,
     DistanceSpec,
+    Either,
     Enum,
     Float,
     Include,
@@ -64,6 +65,7 @@ from ..core.properties import (
     SizeSpec,
     String,
     StringSpec,
+    Tuple,
     field,
     value,
 )
@@ -120,6 +122,8 @@ __all__ = (
     'ImageURL',
     'Line',
     'Marker',
+    'MathMLGlyph',
+    'MathTextGlyph',
     'MultiLine',
     'MultiPolygons',
     'Patch',
@@ -131,6 +135,7 @@ __all__ = (
     'Scatter',
     'Segment',
     'Step',
+    'TeXGlyph',
     'Text',
     'VArea',
     'VAreaStep',
@@ -424,11 +429,11 @@ class Block(LRTBGlyph):
     The y-coordinates of the centers of the blocks.
     """)
 
-    width = NumberSpec(default=1, help="""
+    width = DistanceSpec(default=1, help="""
     The widths of the blocks.
     """)
 
-    height = NumberSpec(default=1, help="""
+    height = DistanceSpec(default=1, help="""
     The heights of the blocks.
     """)
 
@@ -444,7 +449,7 @@ class Block(LRTBGlyph):
     The {prop} values for the blocks.
     """)
 
-class Circle(Marker):
+class Circle(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
     ''' Render circle markers. '''
 
     # explicit __init__ to support Init signatures
@@ -453,16 +458,19 @@ class Circle(Marker):
 
     __example__ = "examples/reference/models/Circle.py"
 
-    _args = ('x', 'y')
+    _args = ('x', 'y', 'radius')
 
-    radius = NullDistanceSpec(help="""
+    x = NumberSpec(default=field("x"), help="""
+    The x-coordinates of the center of the annuli.
+    """)
+
+    y = NumberSpec(default=field("y"), help="""
+    The y-coordinates of the center of the annuli.
+    """)
+
+    radius = DistanceSpec(default=field("radius"), help="""
     The radius values for circle markers (in |data units|, by default).
 
-    .. note::
-        Circle markers are slightly unusual in that they support specifying
-        a radius in addition to a size. Only one of ``radius`` or ``size``
-        should be given.
-
     .. warning::
         Note that ``Circle`` glyphs are always drawn as circles on the screen,
         even in cases where the data space aspect ratio is not 1-1. In all
@@ -485,6 +493,24 @@ class Circle(Marker):
     and y dimensions and use the maximum of the two, 'min' selects the minimum.
     """)
 
+    hit_dilation = Size(default=1.0, help="""
+    The factor by which to dilate the hit radius which is responsible for
+    defining the range in which a glyph responds to interactions with the
+    hover and tap tools.
+    """)
+
+    line_props = Include(LineProps, help="""
+    The {prop} values for the markers.
+    """)
+
+    fill_props = Include(FillProps, help="""
+    The {prop} values for the markers.
+    """)
+
+    hatch_props = Include(HatchProps, help="""
+    The {prop} values for the markers.
+    """)
+
 class Ellipse(XYGlyph, LineGlyph, FillGlyph, HatchGlyph):
     ''' Render ellipses.
 
@@ -625,7 +651,7 @@ class HBar(LRTBGlyph):
     The y-coordinates of the centers of the horizontal bars.
     """)
 
-    height = NumberSpec(default=1, help="""
+    height = DistanceSpec(default=1, help="""
     The heights of the vertical bars.
     """)
 
@@ -1533,6 +1559,26 @@ class Text(XYGlyph, TextGlyph):
         This property is experimental and may change at any point.
     """)
 
+    outline_shape = DataSpec(Enum(OutlineShapeName), default="box", help="""
+    Specify the shape of the outline for the text box.
+
+    The default outline is of a text box is its bounding box (or rectangle).
+    This can be changed to a selection of pre-defined shapes, like circle,
+    ellipse, diamond, parallelogram, etc. Those shapes are circumscribed onto
+    the bounding box, so that the contents of a box fit inside those shapes.
+
+    This property is in effect only when either border line, background fill
+    and/or background hatch properties are set. The user can choose ``"none"``
+    to avoid drawing any shape, even if border or background visuals are set.
+
+    .. note::
+        This property is experimental and may change at any point.
+
+    .. note::
+        Currently hit testing only uses the bounding box of text contents
+        of the glyph, which is equivalent to using box/rectangle shape.
+    """)
+
     text_props = Include(TextProps, help="""
     The {prop} values for the text.
     """)
@@ -1555,6 +1601,80 @@ class Text(XYGlyph, TextGlyph):
 
     border_line_color = Override(default=None)
 
+@abstract
+class MathTextGlyph(Text):
+    """ Base class for math text glyphs.
+
+    """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+class MathMLGlyph(MathTextGlyph):
+    """ Render mathematical content using `MathML <https://www.w3.org/Math/>`_
+    notation.
+
+    See :ref:`ug_styling_mathtext` in the |user guide| for more information.
+
+    """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+class TeXGlyph(MathTextGlyph):
+    """
+    Render mathematical content using `LaTeX <https://www.latex-project.org/>`_
+    notation.
+
+    See :ref:`ug_styling_mathtext` in the |user guide| for more information.
+
+    .. note::
+        Bokeh uses `MathJax <https://www.mathjax.org>`_ to render text
+        containing mathematical notation.
+
+        MathJax only supports math-mode macros (no text-mode macros). You
+        can see more about differences between standard TeX/LaTeX and MathJax
+        here: https://docs.mathjax.org/en/latest/input/tex/differences.html
+
+    """
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    macros = Dict(String, Either(String, Tuple(String, Int)), help="""
+    User defined TeX macros.
+
+    This is a mapping from control sequence names (without leading backslash) to
+    either replacement strings or tuples of a replacement string and a number
+    of arguments.
+
+    Example:
+
+    .. code-block:: python
+
+        TeX(text=r"\\R \\rightarrow \\R^2", macros={"RR": r"{\\bf R}"})
+
+    """)
+
+    display = Either(Enum("inline", "block", "auto"), default="auto", help="""
+    Defines how the text is interpreted and what TeX display mode to use.
+
+    The following values are allowed:
+
+    * ``"auto"`` (the default)
+      The text is parsed, requiring TeX delimiters to enclose math content,
+      e.g. ``"$$x^2$$"`` or ``r"\\[\\frac{x}{y}\\]"``. This allows mixed
+      math text and regular text content. TeX display mode is inferred by
+      the parser.
+    * ``"block"``
+      The text is taken verbatim and TeX's block mode is used.
+    * ``"inline"``
+      The text is taken verbatim and TeX's inline mode is used.
+    """)
+
 class VArea(FillGlyph, HatchGlyph):
     ''' Render a vertically directed area between two equal length sequences
     of y-coordinates with the same x-coordinates.
@@ -1649,7 +1769,7 @@ class VBar(LRTBGlyph):
     The x-coordinates of the centers of the vertical bars.
     """)
 
-    width = NumberSpec(default=1, help="""
+    width = DistanceSpec(default=1, help="""
     The widths of the vertical bars.
     """)
 
