@@ -50,7 +50,7 @@ from ..core.enums import (
     Anchor,
     Dimension,
     Dimensions,
-    KeyModifier,
+    KeyModifierType,
     RegionSelectionMode,
     SelectionMode,
     ToolIcon,
@@ -96,7 +96,7 @@ from ..model import Model
 from ..util.strings import nice_join
 from .annotations import BoxAnnotation, PolyAnnotation, Span
 from .callbacks import Callback
-from .dom import Template
+from .dom import DOMElement
 from .glyphs import (
     HStrip,
     Line,
@@ -108,6 +108,7 @@ from .glyphs import (
     VStrip,
     XYGlyph,
 )
+from .misc.group_by import GroupBy, GroupByModels, GroupByName
 from .nodes import Node
 from .ranges import Range
 from .renderers import DataRenderer, GlyphRenderer
@@ -159,6 +160,25 @@ __all__ = (
     'ZoomOutTool',
 )
 
+# TODO can't clone Struct(), so use a lambda for now
+Modifiers = lambda **kwargs: Struct(shift=Optional(Bool), ctrl=Optional(Bool), alt=Optional(Bool), **kwargs)
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+def _parse_modifiers(value: str) -> dict[KeyModifierType, bool]:
+    keys = [key.strip() for key in value.split("+")]
+    modifiers: dict[KeyModifierType, bool] = {}
+    for key in keys:
+        match key:
+            case "alt":   modifiers["alt"]   = True
+            case "ctrl":  modifiers["ctrl"]  = True
+            case "shift": modifiers["shift"] = True
+            case _:
+                raise ValueError(f"can't parse '{value}' key modifiers; unknown '{key}' key")
+    return modifiers
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
@@ -377,25 +397,25 @@ class Toolbar(UIElement):
     A list of tools to add to the plot.
     """)
 
-    active_drag: Literal["auto"] | Drag | None = Either(Null, Auto, Instance(Drag), default="auto", help="""
+    active_drag: Literal["auto"] | Drag | ToolProxy | None = Either(Null, Auto, Instance(Drag), Instance(ToolProxy), default="auto", help="""
     Specify a drag tool to be active when the plot is displayed.
     """)
 
-    active_inspect: Literal["auto"] | InspectTool | tp.Sequence[InspectTool] | None = \
-        Either(Null, Auto, Instance(InspectTool), Seq(Instance(InspectTool)), default="auto", help="""
+    active_inspect: Literal["auto"] | InspectTool | ToolProxy | tp.Sequence[InspectTool] | None = \
+        Either(Null, Auto, Instance(InspectTool), Instance(ToolProxy), Seq(Instance(InspectTool)), default="auto", help="""
     Specify an inspection tool or sequence of inspection tools to be active when
     the plot is displayed.
     """)
 
-    active_scroll: Literal["auto"] | Scroll | None = Either(Null, Auto, Instance(Scroll), default="auto", help="""
+    active_scroll: Literal["auto"] | Scroll | ToolProxy | None = Either(Null, Auto, Instance(Scroll), Instance(ToolProxy), default="auto", help="""
     Specify a scroll/pinch tool to be active when the plot is displayed.
     """)
 
-    active_tap: Literal["auto"] | Tap | None = Either(Null, Auto, Instance(Tap), default="auto", help="""
+    active_tap: Literal["auto"] | Tap | ToolProxy | None = Either(Null, Auto, Instance(Tap), Instance(ToolProxy), default="auto", help="""
     Specify a tap/click tool to be active when the plot is displayed.
     """)
 
-    active_multi: Literal["auto"] | GestureTool | None = Either(Null, Auto, Instance(GestureTool), default="auto", help="""
+    active_multi: Literal["auto"] | GestureTool | ToolProxy | None = Either(Null, Auto, Instance(GestureTool), Instance(ToolProxy), default="auto", help="""
     Specify an active multi-gesture tool, for instance an edit tool or a range
     tool.
 
@@ -512,6 +532,25 @@ class RangeTool(Tool):
     A shaded annotation drawn to indicate the configured ranges.
     """)
 
+    start_gesture = Enum("pan", "tap", "none", default="none", help="""
+    Which gesture will start a range update interaction in a new location.
+
+    When the value is ``"pan"``, a new range starts at the location where
+    a pointer drag operation begins. The range is updated continuously while
+    the drag operation continues. Ending the drag operation sets the final
+    value of the range.
+
+    When the value is ``"tap"``, a new range starts at the location where
+    a single tap is made. The range is updated continuously while the pointer
+    moves. Tapping at another location sets the final value of the range.
+
+    When the value is ``"none"``, only existing range definitions may be
+    updated, by dragging their edges or interiors.
+
+    Configuring this property allows to make this tool simultaneously co-exist
+    with another tool that would otherwise share a gesture.
+    """)
+
     @error(NO_RANGE_TOOL_RANGES)
     def _check_no_range_tool_ranges(self):
         if self.x_range is None and self.y_range is None:
@@ -538,6 +577,35 @@ class WheelPanTool(Scroll):
     wheel pan tool will pan the plot along the x-axis.
     """)
 
+    modifiers = Modifiers(default={}, help="""
+    Allows to configure a combination of modifier keys, which need to
+    be pressed during the selected gesture for this tool to trigger.
+
+    For example, to pan only when ``Ctrl`` and ``Shift`` keys are
+    pressed, use:
+
+    .. code-block:: python
+
+        tool = WheelPanTool(modifiers=dict(ctrl=True, shift=True))
+        plot.add_tools(tool)
+
+    or alternatively using a concise syntax:
+
+    .. code-block:: python
+
+        tool = WheelPanTool(modifiers="ctrl+shift")
+        plot.add_tools(tool)
+
+    .. note::
+        Setting modifiers allows this tool to be automatically activated,
+        if ``Toolbar.active_scroll`` is set to ``"auto"``.
+
+    .. warning::
+        Configuring modifiers is a platform dependent feature and
+        can make this tool unusable for example on mobile devices.
+
+    """).accepts(String, _parse_modifiers)
+
 class WheelZoomTool(Scroll):
     ''' *toolbar icon*: |wheel_zoom_icon|
 
@@ -579,6 +647,42 @@ class WheelZoomTool(Scroll):
     """)
     # }
 
+    hit_test = Bool(default=False, help="""
+    Whether to zoom only those renderer that are being pointed at.
+
+    This setting only applies when zooming renderers that were configured with
+    sub-coordinates, otherwise it has no effect.
+
+    If ``True``, then ``hit_test_mode`` property defines how hit testing
+    is performed and ``hit_test_behavior`` allows to configure other aspects
+    of this setup. See respective properties for details.
+
+    .. note::
+        This property is experimental and may change at any point
+    """)
+
+    hit_test_mode = Enum("point", "hline", "vline", default="point", help="""
+    Allows to configure what geometry to use when ``hit_test`` is enabled.
+
+    Supported modes are ``"point"`` for single point hit testing, and ``hline``
+    and ``vline`` for either horizontal or vertical span hit testing.
+
+    .. note::
+        This property is experimental and may change at any point
+    """)
+
+    hit_test_behavior = Either(Instance(GroupBy), Enum("only_hit"), default="only_hit", help="""
+    Allows to configure which renderers will be zoomed when ``hit_test`` is enabled.
+
+    By default (``hit_only``) only actually hit renderers will be zoomed. An
+    instance of ``GroupBy`` model can be used to tell what other renderers
+    should be zoomed when a given one is hit.
+
+    .. note::
+        This property is experimental and may change at any point
+    """).accepts(Enum("group_by_name"), lambda _: GroupByName()) \
+        .accepts(List(List(Instance(DataRenderer))), lambda groups: GroupByModels(groups=groups))
+
     maintain_focus = Bool(default=True, help="""
     If True, then hitting a range bound in any one dimension will prevent all
     further zooming all dimensions. If False, zooming can continue
@@ -612,6 +716,35 @@ class WheelZoomTool(Scroll):
     0.001 and 0.09. High values will be clipped. Speed may very between browsers.
     """)
 
+    modifiers = Modifiers(default={}, help="""
+    Allows to configure a combination of modifier keys, which need to
+    be pressed during the selected gesture for this tool to trigger.
+
+    For example, to zoom only when ``Ctrl`` and ``Shift`` keys are
+    pressed, use:
+
+    .. code-block:: python
+
+        tool = WheelZoomTool(modifiers=dict(ctrl=True, shift=True))
+        plot.add_tools(tool)
+
+    or alternatively using a concise syntax:
+
+    .. code-block:: python
+
+        tool = WheelZoomTool(modifiers="ctrl+shift")
+        plot.add_tools(tool)
+
+    .. note::
+        Setting modifiers allows this tool to be automatically activated,
+        if ``Toolbar.active_scroll`` is set to ``"auto"``.
+
+    .. warning::
+        Configuring modifiers is a platform dependent feature and
+        can make this tool unusable for example on mobile devices.
+
+    """).accepts(String, _parse_modifiers)
+
 class CustomAction(ActionTool):
     ''' Execute a custom action, e.g. ``CustomJS`` callback when a toolbar
     icon is activated.
@@ -743,15 +876,30 @@ class TapTool(Tap, SelectTool):
     either a single or double tap.
     """)
 
-    modifiers = Struct(shift=Optional(Bool), ctrl=Optional(Bool), alt=Optional(Bool), default={}, help="""
+    modifiers = Modifiers(default={}, help="""
     Allows to configure a combination of modifier keys, which need to
     be pressed during the selected gesture for this tool to trigger.
 
+    For example, to accept tap events only when ``Ctrl`` and ``Shift``
+    keys are pressed, use:
+
+    .. code-block:: python
+
+        tool = TapTool(modifiers=dict(ctrl=True, shift=True))
+        plot.add_tools(tool)
+
+    or alternatively using a concise syntax:
+
+    .. code-block:: python
+
+        tool = TapTool(modifiers="ctrl+shift")
+        plot.add_tools(tool)
+
     .. warning::
         Configuring modifiers is a platform dependent feature and
         can make this tool unusable for example on mobile devices.
 
-    """).accepts(Enum(KeyModifier), lambda key_mod: {key_mod: True})
+    """).accepts(String, _parse_modifiers)
 
     callback = Nullable(Instance(Callback), help="""
     A callback to execute *whenever a glyph is "hit"* by a mouse click
@@ -1303,12 +1451,12 @@ class HoverTool(InspectTool):
     :geometry: object containing the coordinates of the hover cursor
     """)
 
-    tooltips = Either(Null, Instance(Template), String, List(Tuple(String, String)),
-            default=[
-                ("index","$index"),
-                ("data (x, y)","($x, $y)"),
-                ("screen (x, y)","($sx, $sy)"),
-            ], help="""
+    tooltips = Either(Null, Instance(DOMElement), String, List(Tuple(String, String)),
+        default=[
+            ("index","$index"),
+            ("data (x, y)","($x, $y)"),
+            ("screen (x, y)","($sx, $sy)"),
+        ], help="""
     The (name, field) pairs describing what the hover tool should
     display when there is a hit.
 
@@ -1874,10 +2022,6 @@ class LineEditTool(EditTool, Drag, Tap):
 # Dev API
 #-----------------------------------------------------------------------------
 
-#-----------------------------------------------------------------------------
-# Private API
-#-----------------------------------------------------------------------------
-
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
@@ -1900,6 +2044,8 @@ Tool.register_alias("click", lambda: TapTool(behavior="inspect"))
 Tool.register_alias("tap", lambda: TapTool())
 Tool.register_alias("doubletap", lambda: TapTool(gesture="doubletap"))
 Tool.register_alias("crosshair", lambda: CrosshairTool())
+Tool.register_alias("xcrosshair", lambda: CrosshairTool(dimensions="width"))
+Tool.register_alias("ycrosshair", lambda: CrosshairTool(dimensions="height"))
 Tool.register_alias("box_select", lambda: BoxSelectTool())
 Tool.register_alias("xbox_select", lambda: BoxSelectTool(dimensions="width"))
 Tool.register_alias("ybox_select", lambda: BoxSelectTool(dimensions="height"))
