@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -49,6 +49,7 @@ from ..models import (
     CoordinateMapping,
     DataRange1d,
     GraphRenderer,
+    LayoutProvider,
     Plot,
     Range,
     Scale,
@@ -468,18 +469,18 @@ class figure(Plot, GlyphAPI):
                 p.line(y=stack('2016', '2017'), x='x', color='red',  source=source, name='2017')
 
         '''
-        if all(isinstance(val, (list, tuple)) for val in (x,y)):
+        if all(isinstance(val, list | tuple) for val in (x,y)):
             raise ValueError("Only one of x or y may be a list of stackers")
 
         result = []
 
-        if isinstance(y, (list, tuple)):
+        if isinstance(y, list | tuple):
             kw['x'] = x
             for kw in single_stack(y, "y", **kw):
                 result.append(self.line(**kw))
             return result
 
-        if isinstance(x, (list, tuple)):
+        if isinstance(x, list | tuple):
             kw['y'] = y
             for kw in single_stack(x, "x", **kw):
                 result.append(self.line(**kw))
@@ -649,7 +650,7 @@ class figure(Plot, GlyphAPI):
         '''
         return self._line_stack(y=stackers, **kw)
 
-    def graph(self, node_source, edge_source, layout_provider, **kwargs):
+    def graph(self, node_source: ColumnDataSource, edge_source: ColumnDataSource, layout_provider: LayoutProvider, **kwargs):
         ''' Creates a network graph using the given node, edge and layout provider.
 
         Args:
